@@ -17,12 +17,17 @@ static Eina_Bool _e_desk_show_animator(void *data);
 static void      _e_desk_hide_begin(E_Desk *desk, int mode, int dx, int dy);
 static void      _e_desk_hide_end(E_Desk *desk);
 static Eina_Bool _e_desk_hide_animator(void *data);
+#if (ECORE_VERSION_MAJOR > 1) || (ECORE_VERSION_MINOR >= 8)
+static void      _e_desk_event_desk_window_profile_change_free(void *data, void *ev);
+static void      _e_desk_window_profile_change_protocol_set(void);
+#endif
 
 EAPI int E_EVENT_DESK_SHOW = 0;
 EAPI int E_EVENT_DESK_BEFORE_SHOW = 0;
 EAPI int E_EVENT_DESK_AFTER_SHOW = 0;
 EAPI int E_EVENT_DESK_DESKSHOW = 0;
 EAPI int E_EVENT_DESK_NAME_CHANGE = 0;
+EAPI int E_EVENT_DESK_WINDOW_PROFILE_CHANGE = 0;
 
 EINTERN int
 e_desk_init(void)
@@ -32,6 +37,7 @@ e_desk_init(void)
    E_EVENT_DESK_AFTER_SHOW = ecore_event_type_new();
    E_EVENT_DESK_DESKSHOW = ecore_event_type_new();
    E_EVENT_DESK_NAME_CHANGE = ecore_event_type_new();
+   E_EVENT_DESK_WINDOW_PROFILE_CHANGE = ecore_event_type_new();
    return 1;
 }
 
@@ -47,6 +53,9 @@ e_desk_new(E_Zone *zone, int x, int y)
    E_Desk *desk;
    Eina_List *l;
    E_Config_Desktop_Name *cfname;
+#if (ECORE_VERSION_MAJOR > 1) || (ECORE_VERSION_MINOR >= 8)
+   E_Config_Desktop_Window_Profile *cfprof;
+#endif
    char name[40];
    int ok = 0;
 
@@ -79,7 +88,28 @@ e_desk_new(E_Zone *zone, int x, int y)
         snprintf(name, sizeof(name), _(e_config->desktop_default_name), x, y);
         desk->name = eina_stringshare_add(name);
      }
+#if (ECORE_VERSION_MAJOR > 1) || (ECORE_VERSION_MINOR >= 8)
+   /* Get window profile name for current desktop */
+   ok = 0;
+   EINA_LIST_FOREACH(e_config->desktop_window_profiles, l, cfprof)
+     {
+        if ((cfprof->container >= 0) &&
+            ((int)zone->container->num != cfprof->container)) continue;
+        if ((cfprof->zone >= 0) &&
+            ((int)zone->num != cfprof->zone)) continue;
+        if ((cfprof->desk_x != desk->x) || (cfprof->desk_y != desk->y))
+          continue;
+        desk->window_profile = eina_stringshare_add(cfprof->profile);
+        ok = 1;
+        break;
+     }
 
+   if (!ok)
+     {
+        desk->window_profile = eina_stringshare_add
+          (e_config->desktop_default_window_profile);
+     }
+#endif
    return desk;
 }
 
@@ -223,8 +253,26 @@ e_desk_show(E_Desk *desk)
              if (desk2->visible)
                {
                   desk2->visible = 0;
-                  dx = desk->x - desk2->x;
-                  dy = desk->y - desk2->y;
+                  if (e_config->desk_flip_wrap)
+                    {
+                       /* current desk (desk2) is last desk, switching to first desk (desk) */
+                       if ((!desk->x) && (!desk->y) && (desk2->x + 1 == desk->zone->desk_x_count) && (desk2->y + 1 == desk->zone->desk_y_count))
+                         {
+                            dx = (desk->x != desk2->x) ? 1 : 0;
+                            dy = (desk->y != desk2->y) ? 1 : 0;
+                         }
+                       /* current desk (desk2) is first desk, switching to last desk (desk) */
+                       else if ((!desk2->x) && (!desk2->y) && (desk->x + 1 == desk->zone->desk_x_count) && (desk->y + 1 == desk->zone->desk_y_count))
+                         {
+                            dx = (desk->x != desk2->x) ? -1 : 0;
+                            dy = (desk->y != desk2->y) ? -1 : 0;
+                         }
+                    }
+                  if ((!dx) && (!dy))
+                    {
+                       dx = desk->x - desk2->x;
+                       dy = desk->y - desk2->y;
+                    }
                   if (e_config->desk_flip_animate_mode > 0)
                     _e_desk_hide_begin(desk2, e_config->desk_flip_animate_mode,
                                        dx, dy);
@@ -233,6 +281,8 @@ e_desk_show(E_Desk *desk)
           }
      }
 
+   desk->zone->desk_x_prev = desk->zone->desk_x_current;
+   desk->zone->desk_y_prev = desk->zone->desk_y_current;
    desk->zone->desk_x_current = desk->x;
    desk->zone->desk_y_current = desk->y;
    desk->visible = 1;
@@ -252,7 +302,7 @@ e_desk_show(E_Desk *desk)
         bl = e_container_border_list_first(desk->zone->container);
         while ((bd = e_container_border_list_next(bl)))
           {
-             if ((bd->desk->zone == desk->zone) && (!bd->iconic))
+             if ((!bd->hidden) && (bd->desk->zone == desk->zone) && (!bd->iconic))
                {
                   if ((bd->desk == desk) || (bd->sticky))
                     e_border_show(bd);
@@ -285,30 +335,7 @@ e_desk_show(E_Desk *desk)
 
    EINA_LIST_FOREACH(e_shelf_list(), l, es)
      {
-        Eina_List *ll;
-        E_Config_Shelf *cf_es;
-        E_Zone *zone;
-        E_Config_Shelf_Desk *sd;
-        int show_shelf = 0;
-
-        if (!es) continue;
-        if (!es->cfg->desk_show_mode) continue;
-        cf_es = es->cfg;
-        if (!cf_es) continue;
-
-        zone = e_util_zone_current_get(e_manager_current_get());
-        if (cf_es->zone != (int)zone->num) continue;
-
-        EINA_LIST_FOREACH(es->cfg->desk_list, ll, sd)
-          {
-             if (!sd) continue;
-             if ((desk->x == sd->x) && (desk->y == sd->y))
-               {
-                  show_shelf = 1;
-                  break;
-               }
-          }
-        if (show_shelf)
+        if (e_shelf_desk_visible(es, desk))
           e_shelf_show(es);
         else
           e_shelf_hide(es);
@@ -345,16 +372,19 @@ e_desk_deskshow(E_Zone *zone)
           {
              if (desk->deskshow_toggle)
                {
-                  if (bd->deskshow) e_border_uniconify(bd);
-                  bd->deskshow = 0;
+                  if (bd->deskshow)
+                    {
+                        bd->deskshow = 0;
+                        e_border_uniconify(bd);
+                    }
                }
              else
                {
                   if (bd->iconic) continue;
                   if (bd->client.netwm.state.skip_taskbar) continue;
                   if (bd->user_skip_winlist) continue;
-                  e_border_iconify(bd);
                   bd->deskshow = 1;
+                  e_border_iconify(bd);
                }
           }
      }
@@ -387,7 +417,7 @@ e_desk_last_focused_focus(E_Desk *desk)
              /* this was the window last focused in this desktop */
              if (!bd->lock_focus_out)
                {
-                  e_border_focus_set(bd, 1, 1);
+                  e_border_focus_set_with_pointer(bd);
                   break;
                }
           }
@@ -423,7 +453,7 @@ e_desk_current_get(E_Zone *zone)
 {
    E_OBJECT_CHECK_RETURN(zone, NULL);
    E_OBJECT_TYPE_CHECK_RETURN(zone, E_ZONE_TYPE, NULL);
-
+   
    return e_desk_at_xy_get(zone, zone->desk_x_current, zone->desk_y_current);
 }
 
@@ -438,6 +468,7 @@ e_desk_at_xy_get(E_Zone *zone, int x, int y)
    else if ((x < 0) || (y < 0))
      return NULL;
 
+   if (!zone->desks) return NULL;
    return zone->desks[x + (y * zone->desk_x_count)];
 }
 
@@ -517,6 +548,126 @@ e_desk_prev(E_Zone *zone)
    e_desk_show(e_desk_at_xy_get(zone, x, y));
 }
 
+#if (ECORE_VERSION_MAJOR > 1) || (ECORE_VERSION_MINOR >= 8)
+EAPI void
+e_desk_window_profile_set(E_Desk     *desk,
+                          const char *profile)
+{
+   E_Event_Desk_Window_Profile_Change *ev;
+
+   E_OBJECT_CHECK(desk);
+   E_OBJECT_TYPE_CHECK(desk, E_DESK_TYPE);
+
+   eina_stringshare_replace(&desk->window_profile, profile);
+
+   ev = E_NEW(E_Event_Desk_Window_Profile_Change, 1);
+   ev->desk = desk;
+   e_object_ref(E_OBJECT(desk));
+   ecore_event_add(E_EVENT_DESK_WINDOW_PROFILE_CHANGE, ev,
+                   _e_desk_event_desk_window_profile_change_free, NULL);
+}
+
+EAPI void
+e_desk_window_profile_add(int         container,
+                          int         zone,
+                          int         desk_x,
+                          int         desk_y,
+                          const char *profile)
+{
+   E_Config_Desktop_Window_Profile *cfprof;
+
+   e_desk_window_profile_del(container, zone, desk_x, desk_y);
+
+   cfprof = E_NEW(E_Config_Desktop_Window_Profile, 1);
+   cfprof->container = container;
+   cfprof->zone = zone;
+   cfprof->desk_x = desk_x;
+   cfprof->desk_y = desk_y;
+   if (profile) cfprof->profile = eina_stringshare_add(profile);
+   else cfprof->profile = NULL;
+   e_config->desktop_window_profiles = eina_list_append(e_config->desktop_window_profiles, cfprof);
+}
+
+EAPI void
+e_desk_window_profile_del(int container,
+                          int zone,
+                          int desk_x,
+                          int desk_y)
+{
+   Eina_List *l = NULL;
+   E_Config_Desktop_Window_Profile *cfprof = NULL;
+
+   EINA_LIST_FOREACH(e_config->desktop_window_profiles, l, cfprof)
+     {
+        if (!((cfprof->container == container) &&
+              (cfprof->zone == zone) &&
+              (cfprof->desk_x == desk_x) &&
+              (cfprof->desk_y == desk_y)))
+          continue;
+
+        e_config->desktop_window_profiles =
+          eina_list_remove_list(e_config->desktop_window_profiles, l);
+        if (cfprof->profile) eina_stringshare_del(cfprof->profile);
+        E_FREE(cfprof);
+        break;
+     }
+}
+
+EAPI void
+e_desk_window_profile_update(void)
+{
+   Eina_List *m, *c, *z, *l;
+   E_Manager *man;
+   E_Container *con;
+   E_Zone *zone;
+   E_Desk *desk;
+   E_Config_Desktop_Window_Profile *cfprof;
+   int d_x, d_y, ok;
+
+   _e_desk_window_profile_change_protocol_set();
+
+   if (!(e_config->use_desktop_window_profile))
+     return;
+
+   EINA_LIST_FOREACH(e_manager_list(), m, man)
+     {
+        EINA_LIST_FOREACH(man->containers, c, con)
+          {
+             EINA_LIST_FOREACH(con->zones, z, zone)
+               {
+                  for (d_x = 0; d_x < zone->desk_x_count; d_x++)
+                    {
+                       for (d_y = 0; d_y < zone->desk_y_count; d_y++)
+                         {
+                            desk = zone->desks[d_x + zone->desk_x_count * d_y];
+                            ok = 0;
+
+                            EINA_LIST_FOREACH(e_config->desktop_window_profiles, l, cfprof)
+                              {
+                                 if ((cfprof->container >= 0) &&
+                                     ((int)con->num != cfprof->container)) continue;
+                                 if ((cfprof->zone >= 0) &&
+                                     ((int)zone->num != cfprof->zone)) continue;
+                                 if ((cfprof->desk_x != d_x) ||
+                                     (cfprof->desk_y != d_y)) continue;
+                                 e_desk_window_profile_set(desk, cfprof->profile);
+                                 ok = 1;
+                                 break;
+                              }
+
+                            if (!ok)
+                              {
+                                 e_desk_window_profile_set
+                                   (desk, e_config->desktop_default_window_profile);
+                              }
+                         }
+                    }
+               }
+          }
+     }
+}
+#endif
+
 static void
 _e_desk_free(E_Desk *desk)
 {
@@ -576,7 +727,16 @@ _e_desk_event_desk_name_change_free(void *data __UNUSED__, void *event)
    e_object_unref(E_OBJECT(ev->desk));
    free(ev);
 }
-
+#if (ECORE_VERSION_MAJOR > 1) || (ECORE_VERSION_MINOR >= 8)
+static void
+_e_desk_event_desk_window_profile_change_free(void *data __UNUSED__, void *event)
+{
+   E_Event_Desk_Window_Profile_Change *ev;
+   ev = event;
+   e_object_unref(E_OBJECT(ev->desk));
+   E_FREE(ev);
+}
+#endif
 static void
 _e_desk_show_begin(E_Desk *desk, int mode, int dx, int dy)
 {
@@ -687,10 +847,7 @@ _e_desk_show_end(E_Desk *desk)
        (e_config->focus_policy == E_FOCUS_SLOPPY))
      {
         if (e_config->focus_last_focused_per_desktop)
-          {
-             if (!e_border_under_pointer_get(desk, NULL))
-               e_desk_last_focused_focus(desk);
-          }
+          e_desk_last_focused_focus(desk);
      }
    else
      {
@@ -906,3 +1063,17 @@ _e_desk_hide_animator(void *data)
    return ECORE_CALLBACK_RENEW;
 }
 
+#if (ECORE_VERSION_MAJOR > 1) || (ECORE_VERSION_MINOR >= 8)
+static void
+_e_desk_window_profile_change_protocol_set(void)
+{
+   Eina_List *l = NULL;
+   E_Manager *man;
+
+   EINA_LIST_FOREACH(e_manager_list(), l, man)
+     {
+        ecore_x_e_window_profile_supported_set
+          (man->root, e_config->use_desktop_window_profile);
+     }
+}
+#endif
