@@ -45,6 +45,7 @@ static void _e_entry_cb_paste(void *data, E_Menu *m, E_Menu_Item *mi);
 static void _e_entry_cb_select_all(void *data, E_Menu *m, E_Menu_Item *mi);
 static void _e_entry_cb_delete(void *data, E_Menu *m , E_Menu_Item *mi );
 static void _e_entry_mouse_down_cb(void *data, Evas *e, Evas_Object *obj, void *event_info);
+static void _entry_recalc_size(Evas_Object *object);
 /* local subsystem globals */
 static Evas_Smart *_e_entry_smart = NULL;
 static int _e_entry_smart_use = 0;
@@ -128,6 +129,9 @@ e_entry_text_set(Evas_Object *entry, const char *_text)
    sd->changing--;
    evas_object_smart_callback_call(entry, "changed", NULL);
    free(text);
+
+   edje_object_size_min_calc(sd->entry_object, &sd->min_width, &sd->height);
+   _entry_recalc_size(entry);
 }
 
 /**
@@ -694,6 +698,13 @@ _entry_recalc_size(Evas_Object *object)
    evas_object_geometry_get(sd->entry_object, NULL, NULL, &pw, &ph);
    if ((w == pw) && (h == ph)) return;
    evas_object_resize(sd->entry_object, w, h);
+
+     {
+        Evas_Coord cx, cy, cw, ch;
+        edje_object_part_text_cursor_geometry_get(sd->entry_object,
+              ENTRY_PART_NAME, &cx, &cy, &cw, &ch);
+        e_scrollframe_child_region_show(sd->scroll_object, cx, cy, cw, ch);
+     }
 }
 
 static void
