@@ -245,7 +245,7 @@ main(int argc, char **argv)
    Eina_Bool really_know = EINA_FALSE;
    struct sigaction action;
 #if !defined(__OpenBSD__) && !defined(__NetBSD__) && !defined(__FreeBSD__) && \
-   !(defined (__MACH__) && defined (__APPLE__))
+   !defined(__FreeBSD_kernel__) && !(defined (__MACH__) && defined (__APPLE__))
    Eina_Bool restart = EINA_TRUE;
 #endif
 
@@ -408,14 +408,14 @@ main(int argc, char **argv)
      really_know = EINA_TRUE;
 
 #if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) || \
-   (defined (__MACH__) && defined (__APPLE__))
+   defined(__FreeBSD_kernel__) || (defined (__MACH__) && defined (__APPLE__))
    execv(args[0], args);
 #endif
 
    /* not run at the moment !! */
 
 #if !defined(__OpenBSD__) && !defined(__NetBSD__) && !defined(__FreeBSD__) && \
-   !(defined (__MACH__) && defined (__APPLE__))
+   !defined(__FreeBSD_kernel__) && !(defined (__MACH__) && defined (__APPLE__))
    /* Now looping until */
    while (restart)
      {
@@ -517,8 +517,7 @@ main(int argc, char **argv)
                               {
                                  /* call e_sys gdb */
                                  snprintf(buffer, 4096,
-                                          "%s/enlightenment/utils/enlightenment_sys gdb %i %s/.e-crashdump.txt",
-                                          eina_prefix_lib_get(pfx),
+                                          "gdb %i %s/.e-crashdump.txt",
                                           child,
                                           home);
                                  r = system(buffer);
