@@ -9,24 +9,24 @@
 /* local config structure */
 struct _E_Config_Dialog_Data
 {
-   Eina_List *bindings;
-   Evas_Object *o_bindings, *o_actions, *o_params;
-   Evas_Object *o_add, *o_del;
-   const char *bindex;
+   Eina_List       *bindings;
+   Evas_Object     *o_bindings, *o_actions, *o_params;
+   Evas_Object     *o_add, *o_del;
+   const char      *bindex;
 
    E_Config_Dialog *cfd;
 };
 
 /* local function prototypes */
-static void        *_create_data(E_Config_Dialog *cfd);
-static void         _fill_data(E_Config_Dialog_Data *cfdata);
-static void         _free_data(E_Config_Dialog *cfd  __UNUSED__,
-                               E_Config_Dialog_Data *cfdata);
-static int          _basic_apply(E_Config_Dialog *cfd  __UNUSED__,
-                                 E_Config_Dialog_Data *cfdata);
-static Evas_Object *_basic_create(E_Config_Dialog      *cfd,
-                                  Evas                 *evas,
-                                  E_Config_Dialog_Data *cfdata);
+static void                  *_create_data(E_Config_Dialog *cfd);
+static void                   _fill_data(E_Config_Dialog_Data *cfdata);
+static void                   _free_data(E_Config_Dialog *cfd  __UNUSED__,
+                                         E_Config_Dialog_Data *cfdata);
+static int                    _basic_apply(E_Config_Dialog *cfd  __UNUSED__,
+                                           E_Config_Dialog_Data *cfdata);
+static Evas_Object           *_basic_create(E_Config_Dialog *cfd,
+                                            Evas *evas,
+                                            E_Config_Dialog_Data *cfdata);
 static void                   _fill_bindings(E_Config_Dialog_Data *cfdata);
 static void                   _fill_actions(E_Config_Dialog_Data *cfdata);
 static E_Config_Binding_Acpi *_selected_binding_get(E_Config_Dialog_Data *cfdata);
@@ -34,18 +34,18 @@ static E_Action_Description  *_selected_action_get(E_Config_Dialog_Data *cfdata)
 static const char            *_binding_label_get(E_Config_Binding_Acpi *bind);
 static void                   _cb_bindings_changed(void *data);
 static void                   _cb_actions_changed(void *data);
-static void                   _cb_entry_changed(void       *data,
+static void                   _cb_entry_changed(void *data,
                                                 void *data2 __UNUSED__);
-static void                   _cb_add_binding(void       *data,
+static void                   _cb_add_binding(void *data,
                                               void *data2 __UNUSED__);
-static void                   _cb_del_binding(void       *data,
+static void                   _cb_del_binding(void *data,
                                               void *data2 __UNUSED__);
-static Eina_Bool              _cb_grab_key_down(void    *data,
+static Eina_Bool              _cb_grab_key_down(void *data,
                                                 int type __UNUSED__,
-                                                void    *event);
-static Eina_Bool _cb_acpi_event(void *data,
-                                int   type,
-                                void *event);
+                                                void *event);
+static Eina_Bool              _cb_acpi_event(void *data,
+                                             int type,
+                                             void *event);
 
 /* local variables */
 static E_Dialog *grab_dlg = NULL;
@@ -53,7 +53,7 @@ static Ecore_X_Window grab_win = 0;
 static Eina_List *grab_hdls = NULL;
 
 E_Config_Dialog *
-e_int_config_acpibindings(E_Container       *con,
+e_int_config_acpibindings(E_Container *con,
                           const char *params __UNUSED__)
 {
    E_Config_Dialog *cfd;
@@ -92,18 +92,18 @@ static void
 _fill_data(E_Config_Dialog_Data *cfdata)
 {
    Eina_List *l;
-   E_Config_Binding_Acpi *bind;
+   E_Config_Binding_Acpi *binding;
 
-   EINA_LIST_FOREACH(e_config->acpi_bindings, l, bind)
+   EINA_LIST_FOREACH(e_config->acpi_bindings, l, binding)
      {
         E_Config_Binding_Acpi *b2;
 
         b2 = E_NEW(E_Config_Binding_Acpi, 1);
-        b2->context = bind->context;
-        b2->type = bind->type;
-        b2->status = bind->status;
-        b2->action = eina_stringshare_ref(bind->action);
-        b2->params = eina_stringshare_ref(bind->params);
+        b2->context = binding->context;
+        b2->type = binding->type;
+        b2->status = binding->status;
+        b2->action = eina_stringshare_ref(binding->action);
+        b2->params = eina_stringshare_ref(binding->params);
         cfdata->bindings = eina_list_append(cfdata->bindings, b2);
      }
 }
@@ -112,14 +112,14 @@ static void
 _free_data(E_Config_Dialog *cfd  __UNUSED__,
            E_Config_Dialog_Data *cfdata)
 {
-   E_Config_Binding_Acpi *bind;
+   E_Config_Binding_Acpi *binding;
    Ecore_Event_Handler *hdl;
 
-   EINA_LIST_FREE(cfdata->bindings, bind)
+   EINA_LIST_FREE(cfdata->bindings, binding)
      {
-        if (bind->action) eina_stringshare_del(bind->action);
-        if (bind->params) eina_stringshare_del(bind->params);
-        E_FREE(bind);
+        if (binding->action) eina_stringshare_del(binding->action);
+        if (binding->params) eina_stringshare_del(binding->params);
+        E_FREE(binding);
      }
 
    /* free the handlers */
@@ -147,26 +147,26 @@ static int
 _basic_apply(E_Config_Dialog *cfd  __UNUSED__,
              E_Config_Dialog_Data *cfdata)
 {
-   E_Config_Binding_Acpi *bind, *b2;
+   E_Config_Binding_Acpi *binding, *b2;
    Eina_List *l;
 
-   EINA_LIST_FREE(e_config->acpi_bindings, bind)
+   EINA_LIST_FREE(e_config->acpi_bindings, binding)
      {
-        e_bindings_acpi_del(bind->context, bind->type, bind->status,
-                            bind->action, bind->params);
-        if (bind->action) eina_stringshare_del(bind->action);
-        if (bind->params) eina_stringshare_del(bind->params);
-        E_FREE(bind);
+        e_bindings_acpi_del(binding->context, binding->type, binding->status,
+                            binding->action, binding->params);
+        if (binding->action) eina_stringshare_del(binding->action);
+        if (binding->params) eina_stringshare_del(binding->params);
+        E_FREE(binding);
      }
 
-   EINA_LIST_FOREACH(cfdata->bindings, l, bind)
+   EINA_LIST_FOREACH(cfdata->bindings, l, binding)
      {
         b2 = E_NEW(E_Config_Binding_Acpi, 1);
-        b2->context = bind->context;
-        b2->type = bind->type;
-        b2->status = bind->status;
-        b2->action = eina_stringshare_ref(bind->action);
-        b2->params = eina_stringshare_ref(bind->params);
+        b2->context = binding->context;
+        b2->type = binding->type;
+        b2->status = binding->status;
+        b2->action = eina_stringshare_ref(binding->action);
+        b2->params = eina_stringshare_ref(binding->params);
         e_config->acpi_bindings =
           eina_list_append(e_config->acpi_bindings, b2);
 
@@ -179,8 +179,8 @@ _basic_apply(E_Config_Dialog *cfd  __UNUSED__,
 }
 
 static Evas_Object *
-_basic_create(E_Config_Dialog      *cfd,
-              Evas                 *evas,
+_basic_create(E_Config_Dialog *cfd,
+              Evas *evas,
               E_Config_Dialog_Data *cfdata)
 {
    Evas_Object *ol, *of, *ow, *ot;
@@ -194,11 +194,11 @@ _basic_create(E_Config_Dialog      *cfd,
    _fill_bindings(cfdata);
    e_widget_frametable_object_append(of, ow, 0, 0, 2, 1, 1, 1, 1, 1);
 
-   ow = e_widget_button_add(evas, _("Add Binding"), "list-add",
+   ow = e_widget_button_add(evas, _("Add"), "list-add",
                             _cb_add_binding, cfdata, NULL);
    cfdata->o_add = ow;
    e_widget_frametable_object_append(of, ow, 0, 1, 1, 1, 1, 0, 1, 0);
-   ow = e_widget_button_add(evas, _("Delete Binding"), "list-remove",
+   ow = e_widget_button_add(evas, _("Delete"), "list-remove",
                             _cb_del_binding, cfdata, NULL);
    cfdata->o_del = ow;
    e_widget_disabled_set(ow, EINA_TRUE);
@@ -230,7 +230,7 @@ _fill_bindings(E_Config_Dialog_Data *cfdata)
 {
    Evas *evas;
    Eina_List *l;
-   E_Config_Binding_Acpi *bind;
+   E_Config_Binding_Acpi *binding;
    int i = -1, mw;
 
    evas = evas_object_evas_get(cfdata->o_bindings);
@@ -239,7 +239,7 @@ _fill_bindings(E_Config_Dialog_Data *cfdata)
    e_widget_ilist_freeze(cfdata->o_bindings);
    e_widget_ilist_clear(cfdata->o_bindings);
 
-   EINA_LIST_FOREACH(cfdata->bindings, l, bind)
+   EINA_LIST_FOREACH(cfdata->bindings, l, binding)
      {
         const char *lbl;
         char buff[32];
@@ -247,10 +247,10 @@ _fill_bindings(E_Config_Dialog_Data *cfdata)
         i++;
         snprintf(buff, sizeof(buff), "%d", i);
 
-        lbl = _binding_label_get(bind);
+        lbl = _binding_label_get(binding);
 
         e_widget_ilist_append(cfdata->o_bindings, NULL, lbl,
-                                _cb_bindings_changed, cfdata, buff);
+                              _cb_bindings_changed, cfdata, buff);
      }
 
    e_widget_ilist_go(cfdata->o_bindings);
@@ -301,12 +301,12 @@ _fill_actions(E_Config_Dialog_Data *cfdata)
 static E_Config_Binding_Acpi *
 _selected_binding_get(E_Config_Dialog_Data *cfdata)
 {
-   E_Config_Binding_Acpi *bind;
+   E_Config_Binding_Acpi *binding;
 
    if ((!cfdata) || (!cfdata->bindex)) return NULL;
-   if (!(bind = eina_list_nth(cfdata->bindings, atoi(cfdata->bindex))))
+   if (!(binding = eina_list_nth(cfdata->bindings, atoi(cfdata->bindex))))
      return NULL;
-   return bind;
+   return binding;
 }
 
 static E_Action_Description *
@@ -332,7 +332,7 @@ _selected_action_get(E_Config_Dialog_Data *cfdata)
 //            (strcmp(grp->act_grp, "Launch"))) continue;
         EINA_LIST_FOREACH(grp->acts, ll, dsc)
           {
-             if ((dsc->act_name) && (!strcmp(dsc->act_name, lbl))) 
+             if ((dsc->act_name) && (!strcmp(_(dsc->act_name), lbl)))
                return dsc;
           }
      }
@@ -341,55 +341,55 @@ _selected_action_get(E_Config_Dialog_Data *cfdata)
 }
 
 static const char *
-_binding_label_get(E_Config_Binding_Acpi *bind)
+_binding_label_get(E_Config_Binding_Acpi *binding)
 {
-   if (bind->type == E_ACPI_TYPE_UNKNOWN) return NULL;
-   if (bind->type == E_ACPI_TYPE_AC_ADAPTER)
+   if (binding->type == E_ACPI_TYPE_UNKNOWN) return NULL;
+   if (binding->type == E_ACPI_TYPE_AC_ADAPTER)
      {
-        if (bind->status == 0) return _("AC Adapter Unplugged");
-        if (bind->status == 1) return _("AC Adapter Plugged");
+        if (binding->status == 0) return _("AC Adapter Unplugged");
+        if (binding->status == 1) return _("AC Adapter Plugged");
         return _("Ac Adapter");
      }
-   if (bind->type == E_ACPI_TYPE_BATTERY)
+   if (binding->type == E_ACPI_TYPE_BATTERY)
      return _("Battery");
-   if (bind->type == E_ACPI_TYPE_BUTTON)
+   if (binding->type == E_ACPI_TYPE_BUTTON)
      return _("Button");
-   if (bind->type == E_ACPI_TYPE_FAN)
+   if (binding->type == E_ACPI_TYPE_FAN)
      return _("Fan");
-   if (bind->type == E_ACPI_TYPE_LID)
+   if (binding->type == E_ACPI_TYPE_LID)
      {
-        if (bind->status == E_ACPI_LID_UNKNOWN) return _("Lid Unknown");
-        if (bind->status == E_ACPI_LID_CLOSED) return _("Lid Closed");
-        if (bind->status == E_ACPI_LID_OPEN) return _("Lid Opened");
+        if (binding->status == E_ACPI_LID_UNKNOWN) return _("Lid Unknown");
+        if (binding->status == E_ACPI_LID_CLOSED) return _("Lid Closed");
+        if (binding->status == E_ACPI_LID_OPEN) return _("Lid Opened");
         return _("Lid");
      }
-   if (bind->type == E_ACPI_TYPE_POWER)
+   if (binding->type == E_ACPI_TYPE_POWER)
      return _("Power Button");
-   if (bind->type == E_ACPI_TYPE_PROCESSOR)
+   if (binding->type == E_ACPI_TYPE_PROCESSOR)
      return _("Processor");
-   if (bind->type == E_ACPI_TYPE_SLEEP)
+   if (binding->type == E_ACPI_TYPE_SLEEP)
      return _("Sleep Button");
-   if (bind->type == E_ACPI_TYPE_THERMAL)
+   if (binding->type == E_ACPI_TYPE_THERMAL)
      return _("Thermal");
-   if (bind->type == E_ACPI_TYPE_VIDEO)
+   if (binding->type == E_ACPI_TYPE_VIDEO)
      return _("Video");
-   if (bind->type == E_ACPI_TYPE_WIFI)
+   if (binding->type == E_ACPI_TYPE_WIFI)
      return _("Wifi");
-   if (bind->type == E_ACPI_TYPE_HIBERNATE)
+   if (binding->type == E_ACPI_TYPE_HIBERNATE)
      return _("Hibernate");
-   if (bind->type == E_ACPI_TYPE_ZOOM_OUT)
+   if (binding->type == E_ACPI_TYPE_ZOOM_OUT)
      return _("Zoom Out");
-   if (bind->type == E_ACPI_TYPE_ZOOM_IN)
+   if (binding->type == E_ACPI_TYPE_ZOOM_IN)
      return _("Zoom In");
-   if (bind->type == E_ACPI_TYPE_BRIGHTNESS_DOWN)
+   if (binding->type == E_ACPI_TYPE_BRIGHTNESS_DOWN)
      return _("Brightness Down");
-   if (bind->type == E_ACPI_TYPE_BRIGHTNESS_UP)
+   if (binding->type == E_ACPI_TYPE_BRIGHTNESS_UP)
      return _("Brightness Up");
-   if (bind->type == E_ACPI_TYPE_ASSIST)
+   if (binding->type == E_ACPI_TYPE_ASSIST)
      return _("Assist");
-   if (bind->type == E_ACPI_TYPE_S1)
+   if (binding->type == E_ACPI_TYPE_S1)
      return _("S1");
-   if (bind->type == E_ACPI_TYPE_VAIO)
+   if (binding->type == E_ACPI_TYPE_VAIO)
      return _("Vaio");
 
    return _("Unknown");
@@ -399,14 +399,14 @@ static void
 _cb_bindings_changed(void *data)
 {
    E_Config_Dialog_Data *cfdata;
-   E_Config_Binding_Acpi *bind;
-   Eina_List *items;
+   E_Config_Binding_Acpi *binding;
+   const Eina_List *items;
    const E_Ilist_Item *item;
    int i = -1;
 
    if (!(cfdata = data)) return;
    e_widget_entry_clear(cfdata->o_params);
-   if (!(bind = _selected_binding_get(cfdata)))
+   if (!(binding = _selected_binding_get(cfdata)))
      {
         e_widget_disabled_set(cfdata->o_params, EINA_TRUE);
         e_widget_disabled_set(cfdata->o_del, EINA_TRUE);
@@ -422,7 +422,7 @@ _cb_bindings_changed(void *data)
 
         i++;
         if (!(val = e_widget_ilist_item_value_get(item))) continue;
-        if (strcmp(val, bind->action)) continue;
+        if (strcmp(val, binding->action)) continue;
         e_widget_ilist_selected_set(cfdata->o_actions, i);
         break;
      }
@@ -432,12 +432,12 @@ static void
 _cb_actions_changed(void *data)
 {
    E_Config_Dialog_Data *cfdata;
-   E_Config_Binding_Acpi *bind;
+   E_Config_Binding_Acpi *binding;
    E_Action_Description *dsc;
 
    if (!(cfdata = data)) return;
    e_widget_entry_clear(cfdata->o_params);
-   if (!(bind = _selected_binding_get(cfdata)))
+   if (!(binding = _selected_binding_get(cfdata)))
      {
         e_widget_disabled_set(cfdata->o_params, EINA_TRUE);
         e_widget_disabled_set(cfdata->o_del, EINA_TRUE);
@@ -449,13 +449,13 @@ _cb_actions_changed(void *data)
         return;
      }
 
-   eina_stringshare_replace(&bind->action, dsc->act_cmd);
+   eina_stringshare_replace(&binding->action, dsc->act_cmd);
    e_widget_disabled_set(cfdata->o_params, !(dsc->editable));
 
    if ((!dsc->editable) && (dsc->act_params))
      e_widget_entry_text_set(cfdata->o_params, dsc->act_params);
-   else if (bind->params)
-     e_widget_entry_text_set(cfdata->o_params, bind->params);
+   else if (binding->params)
+     e_widget_entry_text_set(cfdata->o_params, binding->params);
    else
      {
         if ((!dsc->param_example) || (!dsc->param_example[0]))
@@ -466,23 +466,23 @@ _cb_actions_changed(void *data)
 }
 
 static void
-_cb_entry_changed(void       *data,
+_cb_entry_changed(void *data,
                   void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
-   E_Config_Binding_Acpi *bind;
+   E_Config_Binding_Acpi *binding;
    E_Action_Description *dsc;
 
    if (!(cfdata = data)) return;
    if (!(dsc = _selected_action_get(cfdata))) return;
    if (!dsc->editable) return;
-   if (!(bind = _selected_binding_get(cfdata))) return;
-   eina_stringshare_replace(&bind->params,
+   if (!(binding = _selected_binding_get(cfdata))) return;
+   eina_stringshare_replace(&binding->params,
                             e_widget_entry_text_get(cfdata->o_params));
 }
 
 static void
-_cb_add_binding(void       *data,
+_cb_add_binding(void *data,
                 void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
@@ -524,26 +524,26 @@ _cb_add_binding(void       *data,
 }
 
 static void
-_cb_del_binding(void       *data,
+_cb_del_binding(void *data,
                 void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
-   E_Config_Binding_Acpi *bind, *bind2;
+   E_Config_Binding_Acpi *binding, *bind2;
    Eina_List *l;
 
    if (!(cfdata = data)) return;
-   if (!(bind = _selected_binding_get(cfdata))) return;
+   if (!(binding = _selected_binding_get(cfdata))) return;
 
    /* delete from e_config */
    EINA_LIST_FOREACH(e_config->acpi_bindings, l, bind2)
      {
-        if ((bind->context == bind2->context) && (bind->type == bind2->type) &&
-            (((bind->action) && (bind2->action) &&
-              (!strcmp(bind->action, bind2->action))) ||
-             ((!bind->action) && (!bind2->action))) &&
-            (((bind->params) && (bind2->params) &&
-              (!strcmp(bind->params, bind2->params))) ||
-             ((!bind->params) && (!bind2->params))))
+        if ((binding->context == bind2->context) && (binding->type == bind2->type) &&
+            (((binding->action) && (bind2->action) &&
+              (!strcmp(binding->action, bind2->action))) ||
+             ((!binding->action) && (!bind2->action))) &&
+            (((binding->params) && (bind2->params) &&
+              (!strcmp(binding->params, bind2->params))) ||
+             ((!binding->params) && (!bind2->params))))
           {
              if (bind2->action) eina_stringshare_del(bind2->action);
              if (bind2->params) eina_stringshare_del(bind2->params);
@@ -556,19 +556,19 @@ _cb_del_binding(void       *data,
      }
 
    /* delete from e_bindings */
-   e_bindings_acpi_del(bind->context, bind->type, bind->status,
-                       bind->action, bind->params);
+   e_bindings_acpi_del(binding->context, binding->type, binding->status,
+                       binding->action, binding->params);
 
    /* delete from dialog list */
    EINA_LIST_FOREACH(cfdata->bindings, l, bind2)
      {
-        if ((bind->context == bind2->context) && (bind->type == bind2->type) &&
-            (((bind->action) && (bind2->action) &&
-              (!strcmp(bind->action, bind2->action))) ||
-             ((!bind->action) && (!bind2->action))) &&
-            (((bind->params) && (bind2->params) &&
-              (!strcmp(bind->params, bind2->params))) ||
-             ((!bind->params) && (!bind2->params))))
+        if ((binding->context == bind2->context) && (binding->type == bind2->type) &&
+            (((binding->action) && (bind2->action) &&
+              (!strcmp(binding->action, bind2->action))) ||
+             ((!binding->action) && (!bind2->action))) &&
+            (((binding->params) && (bind2->params) &&
+              (!strcmp(binding->params, bind2->params))) ||
+             ((!binding->params) && (!bind2->params))))
           {
              if (bind2->action) eina_stringshare_del(bind2->action);
              if (bind2->params) eina_stringshare_del(bind2->params);
@@ -587,9 +587,9 @@ _cb_del_binding(void       *data,
 }
 
 static Eina_Bool
-_cb_grab_key_down(void    *data,
+_cb_grab_key_down(void *data,
                   int type __UNUSED__,
-                  void    *event)
+                  void *event)
 {
    E_Config_Dialog_Data *cfdata;
    Ecore_Event_Key *ev;
@@ -619,13 +619,13 @@ _cb_grab_key_down(void    *data,
 }
 
 static Eina_Bool
-_cb_acpi_event(void          *data,
+_cb_acpi_event(void *data,
                __UNUSED__ int type,
-               void          *event)
+               void *event)
 {
    E_Event_Acpi *ev;
    E_Config_Dialog_Data *cfdata;
-   E_Config_Binding_Acpi *bind;
+   E_Config_Binding_Acpi *binding;
    Ecore_Event_Handler *hdl;
 
    ev = event;
@@ -646,14 +646,14 @@ _cb_acpi_event(void          *data,
    e_acpi_events_thaw();
 
    /* NB: This may need more testing/parsing for event status */
-   bind = E_NEW(E_Config_Binding_Acpi, 1);
-   bind->context = E_BINDING_CONTEXT_NONE;
-   bind->type = ev->type;
-   bind->status = ev->status;
-   bind->action = eina_stringshare_add("dim_screen");
-   bind->params = NULL;
+   binding = E_NEW(E_Config_Binding_Acpi, 1);
+   binding->context = E_BINDING_CONTEXT_NONE;
+   binding->type = ev->type;
+   binding->status = ev->status;
+   binding->action = eina_stringshare_add("dim_screen");
+   binding->params = NULL;
 
-   cfdata->bindings = eina_list_append(cfdata->bindings, bind);
+   cfdata->bindings = eina_list_append(cfdata->bindings, binding);
    _fill_bindings(cfdata);
    return ECORE_CALLBACK_DONE;
 }
