@@ -2,11 +2,14 @@
 #include "e_mod_main.h"
 #include "e_int_config_randr.h"
 #include "e_smart_randr.h"
+#include "e_smart_monitor.h"
 
 /* local structures */
 struct _E_Config_Dialog_Data
 {
    Evas_Object *o_randr;
+
+   int restore, primary;
 };
 
 /* local function prototypes */
@@ -14,6 +17,8 @@ static void *_create_data(E_Config_Dialog *cfd EINA_UNUSED);
 static void _free_data(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata);
 static Evas_Object *_basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata);
 static int _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata);
+static int _basic_check(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata);
+
 static void _randr_cb_changed(void *data, Evas_Object *obj, void *event EINA_UNUSED);
 
 /* public functions */
@@ -27,10 +32,6 @@ e_int_config_randr(E_Container *con, const char *params EINA_UNUSED)
    if (e_config_dialog_find("E", "screen/screen_setup"))
      return NULL;
 
-   /* check for valid XRandR protocol version */
-   if (e_randr_screen_info.randr_version < ECORE_X_RANDR_1_2)
-     return NULL;
-
    /* try to allocate dialog view */
    if (!(v = E_NEW(E_Config_Dialog_View, 1)))
      return NULL;
@@ -40,6 +41,7 @@ e_int_config_randr(E_Container *con, const char *params EINA_UNUSED)
    v->free_cfdata = _free_data;
    v->basic.create_widgets = _basic_create;
    v->basic.apply_cfdata = _basic_apply;
+   v->basic.check_changed = _basic_check;
    v->override_auto_apply = EINA_TRUE;
 
    /* create new dialog */
@@ -47,7 +49,6 @@ e_int_config_randr(E_Container *con, const char *params EINA_UNUSED)
                              "E", "screen/screen_setup",
                              "preferences-system-screen-resolution", 
                              0, v, NULL);
-   e_dialog_resizable_set(cfd->dia, 1);
 
    return cfd;
 }
@@ -62,6 +63,9 @@ _create_data(E_Config_Dialog *cfd EINA_UNUSED)
    if (!(cfdata = E_NEW(E_Config_Dialog_Data, 1)))
      return NULL;
 
+   cfdata->restore = e_randr_cfg->restore;
+   cfdata->primary = e_randr_cfg->primary;
+
    return cfdata;
 }
 
@@ -71,10 +75,6 @@ _free_data(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
    /* if we have the randr smart widget, delete it */
    if (cfdata->o_randr)
      {
-        /* delete the hook into randr widget changed signal */
-        evas_object_smart_callback_del(cfdata->o_randr, "changed", 
-                                       _randr_cb_changed);
-
         /* delete the randr object */
         evas_object_del(cfdata->o_randr);
      }
@@ -87,7 +87,9 @@ static Evas_Object *
 _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
 {
    Evas_Object *o;
-   Evas_Coord cw = 0, ch = 0;
+   Evas_Object *ow;
+   Evas_Coord mw = 0, mh = 0, ch = 0, fh = 0;
+   Eina_List *l, *monitors = NULL;
 
    /* create the base list widget */
    o = e_widget_list_add(evas, 0, 0);
@@ -95,38 +97,56 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
    /* try to create randr smart widget */
    if ((cfdata->o_randr = e_smart_randr_add(evas)))
      {
-        Evas_Coord lw = 0, lh = 0;
+        /* hook into randr widget changed callback */
+        evas_object_smart_callback_add(cfdata->o_randr, "randr_changed", 
+                                       _randr_cb_changed, cfd);
 
-        /* ask randr widget to compute best layout size based on the 
-         * size of available crtcs */
-        e_smart_randr_layout_size_get(cfdata->o_randr, &lw, &lh);
-
-        /* calculate virtual size
-         * 
-         * NB: Get which size is larger. This is done so that the 
-         * virtual canvas size can be set such that monitors may be 
-         * repositioned easily in a horizontal or vertical layout.
-         * Without using MAX (and just using current size) than a 
-         * horizontal layout cannot be changed into a vertical layout */
-        cw = MAX(lw, lh);
-        ch = MAX(lw, lh);
-
-        /* set the virtual size for the randr widget */
-        e_smart_randr_current_size_set(cfdata->o_randr, cw, ch);
+        /* tell randr widget to calculate virtual size */
+        e_smart_randr_virtual_size_calc(cfdata->o_randr);
 
         /* tell randr widget to create monitors */
         e_smart_randr_monitors_create(cfdata->o_randr);
 
-        /* hook into randr widget changed signal */
-        evas_object_smart_callback_add(cfdata->o_randr, "changed", 
-                                       _randr_cb_changed, cfd);
-
-        /* add randr widget to the base widget */
+        /* append randr widget to list object */
         e_widget_list_object_append(o, cfdata->o_randr, 1, 1, 0.5);
+
+        /* ask randr widget to calculate min size */
+        e_smart_randr_min_size_get(cfdata->o_randr, &mw, &mh);
      }
 
-   /* set a minimum size to 1/10th */
-   e_widget_size_min_set(o, (cw / 10), (ch / 10));
+   monitors = e_smart_randr_monitors_get(cfdata->o_randr);
+   if (eina_list_count(monitors) > 1)
+     {
+        E_Radio_Group *rg;
+        Evas_Object *mon, *of;
+
+        of = e_widget_framelist_add(evas, _("Primary Output"), 0);
+        rg = e_widget_radio_group_new(&(cfdata->primary));
+        EINA_LIST_FOREACH(monitors, l, mon)
+          {
+             int output;
+             const char *name;
+
+             name = e_smart_monitor_name_get(mon);
+             output = (int)e_smart_monitor_output_get(mon);
+
+             ow = e_widget_radio_add(evas, name, output, rg);
+             e_widget_framelist_object_append(of, ow);
+          }
+
+        e_widget_list_object_append(o, of, 1, 0, 0.5);
+        e_widget_size_min_get(of, NULL, &fh);
+     }
+
+   ow = e_widget_check_add(evas, _("Restore On Startup"), &(cfdata->restore));
+   e_widget_list_object_append(o, ow, 1, 0, 0.5);
+   e_widget_size_min_get(ow, NULL, &ch);
+
+   /* set min size of the list widget */
+   e_widget_size_min_set(o, mw, mh + fh + ch);
+
+   e_util_win_auto_resize_fill(cfd->dia->win);
+   e_win_centered_set(cfd->dia->win, 1);
 
    return o;
 }
@@ -134,13 +154,30 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data *cfdata)
 static int 
 _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
 {
-   /* tell randr widget to apply changes */
+   Eina_Bool change_primary = EINA_FALSE;
+
+   change_primary = (e_randr_cfg->primary != cfdata->primary);
+
+   e_randr_cfg->primary = cfdata->primary;
+   e_randr_cfg->restore = cfdata->restore;
+   e_randr_config_save();
+
+   if (change_primary)
+     ecore_x_randr_primary_output_set(ecore_x_window_root_first_get(), 
+                                      (Ecore_X_Randr_Output)cfdata->primary);
+
    e_smart_randr_changes_apply(cfdata->o_randr);
 
-   /* return success */
    return 1;
 }
 
+static int 
+_basic_check(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
+{
+   return ((e_randr_cfg->restore != cfdata->restore) || 
+           (e_randr_cfg->primary != cfdata->primary));
+}
+
 static void 
 _randr_cb_changed(void *data, Evas_Object *obj, void *event EINA_UNUSED)
 {
@@ -149,9 +186,6 @@ _randr_cb_changed(void *data, Evas_Object *obj, void *event EINA_UNUSED)
 
    if (!(cfd = data)) return;
 
-   /* get randr widget changed state */
    changed = e_smart_randr_changed_get(obj);
-
-   /* update dialog with changed state */
    e_config_dialog_changed_set(cfd, changed);
 }
