@@ -1,16 +1,8 @@
 #ifndef E_MOD_MAIN_H
 #define E_MOD_MAIN_H
 
-#define E_TYPEDEFS 1
-#include "e_int_config_wallpaper.h"
-#undef E_TYPEDEFS
-#include "e_int_config_wallpaper.h"
-
-EAPI extern E_Module_Api e_modapi;
-
-EAPI void *e_modapi_init     (E_Module *m);
-EAPI int   e_modapi_shutdown (E_Module *m);
-EAPI int   e_modapi_save     (E_Module *m);
+E_Config_Dialog *wp_conf_show(E_Container *con, const char *params);
+void wp_conf_hide(void);
 
 /**
  * @addtogroup Optional_Conf
