@@ -389,9 +389,11 @@ _place_items(Smart_Data *sd)
 {
    Eina_List *l;
    Item *it;
-   int div;
+   int divider;
    Evas_Coord x = 0, y = 0, ww, hh, mw = 0, mh = 0;
 
+   sd->place = EINA_FALSE;
+
    if (sd->view->mode == VIEW_MODE_LIST)
      {
         ww = sd->w;
@@ -413,9 +415,9 @@ _place_items(Smart_Data *sd)
 
         if ((w > 0) && (h > 0))
           {
-             div = sd->w / w;
-             if (div < 1) div = 1;
-             ww = w + (sd->w - div * w) / div;
+             divider = sd->w / w;
+             if (divider < 1) divider = 1;
+             ww = w + (sd->w - divider * w) / divider;
              hh = ((double)h / (double)w * (double)ww);
           }
         else
@@ -427,16 +429,16 @@ _place_items(Smart_Data *sd)
              else
                ww = 192;
 
-             div = sd->w / ww;
-             if (div < 1) div = 1;
-             ww += (sd->w - div * ww) / div;
+             divider = sd->w / ww;
+             if (divider < 1) divider = 1;
+             ww += (sd->w - divider * ww) / divider;
 
-             div = sd->h / ww;
-             if (div < 1) div = 1;
-             hh = ww + (sd->h - div * ww) / div;
+             divider = sd->h / ww;
+             if (divider < 1) divider = 1;
+             hh = ww + (sd->h - divider * ww) / divider;
 
              if (hh > ww)
-               hh = ww + (sd->h - (div + 1) * ww) / (div + 1);
+               hh = ww + (sd->h - (divider + 1) * ww) / (divider + 1);
           }
      }
 
@@ -490,19 +492,23 @@ _e_smart_reconfigure_do(void *data)
    Eina_List *l;
    Item *it;
    Evas_Coord xx, yy;
-   double time;
+   double t;
 
    if (!sd)
      return ECORE_CALLBACK_CANCEL;
 
-   sd->idle_enter = NULL;
-
    if (sd->w < 1)
-     return ECORE_CALLBACK_CANCEL;
-
+     {
+        sd->idle_enter = NULL;
+        return ECORE_CALLBACK_CANCEL;
+     }
+   
    if (sd->view->hiding)
-     return ECORE_CALLBACK_CANCEL;
-
+     {
+        sd->idle_enter = NULL;
+        return ECORE_CALLBACK_CANCEL;
+     }
+   
    if (sd->cx > (sd->cw - sd->w)) sd->cx = sd->cw - sd->w;
    if (sd->cy > (sd->ch - sd->h)) sd->cy = sd->ch - sd->h;
    if (sd->cx < 0) sd->cx = 0;
@@ -514,7 +520,7 @@ _e_smart_reconfigure_do(void *data)
         return ECORE_CALLBACK_RENEW;
      }
 
-   time = ecore_time_get();
+   t = ecore_time_get();
 
    EINA_LIST_FOREACH (sd->items, l, it)
      {
@@ -536,7 +542,7 @@ _e_smart_reconfigure_do(void *data)
           }
         it->changed = EINA_FALSE;
 
-        if (ecore_time_get() - time > 0.03)
+        if (ecore_time_get() - t > 0.01)
           return ECORE_CALLBACK_RENEW;
      }
 
@@ -572,8 +578,6 @@ _e_smart_del(Evas_Object *obj)
    if (sd->idle_enter)
      ecore_idle_enterer_del(sd->idle_enter);
 
-   _animator_del(obj);
-
    free(sd);
    evas_object_smart_data_set(obj, NULL);
 }
@@ -621,7 +625,7 @@ _pan_add(Evas *evas)
    static Evas_Smart *smart = NULL;
    static const Evas_Smart_Class sc =
    {
-      "wp_pan",
+      "evry_items",
       EVAS_SMART_CLASS_VERSION,
       _e_smart_add,
       _e_smart_del,
@@ -640,7 +644,10 @@ _pan_add(Evas *evas)
       NULL,
       NULL
    };
-   smart = evas_smart_class_new(&sc);
+
+   if (smart == NULL)
+     smart = evas_smart_class_new(&sc);
+
    return evas_object_smart_add(evas, smart);
 }
 
@@ -691,10 +698,10 @@ _pan_child_size_get(Evas_Object *obj, Evas_Coord *w, Evas_Coord *h)
 }
 
 static void
-_pan_view_set(Evas_Object *obj, View *view)
+_pan_view_set(Evas_Object *obj, View *v)
 {
    Smart_Data *sd = evas_object_smart_data_get(obj);
-   sd->view = view;
+   sd->view = v;
 }
 
 static Item *
@@ -773,6 +780,8 @@ _animator(void *data)
                                     0, sd->scroll_align);
      }
 
+   sd->place = EINA_TRUE;
+
    if (wait)
      return ECORE_CALLBACK_RENEW;
 
@@ -893,9 +902,9 @@ _clear_items(Evas_Object *obj)
 }
 
 static void
-_view_clear(Evry_View *view)
+_view_clear(Evry_View *ev)
 {
-   View *v = (View *)view;
+   View *v = (View *)ev;
    Smart_Data *sd = evas_object_smart_data_get(v->span);
    Item *it;
    if (!sd) return;
@@ -942,7 +951,15 @@ _update_frame(Evas_Object *obj)
 
    e_scrollframe_child_pos_set(sd->view->sframe, 0, sd->scroll_align);
 
+
+   if (sd->idle_enter)
+     {
+        ecore_idle_enterer_del(sd->idle_enter);
+        sd->idle_enter = NULL;
+     }
+   
    sd->place = EINA_TRUE;
+   
    _e_smart_reconfigure_do(obj);
 
    _pan_item_select(obj, sd->cur_item, 0);
@@ -953,9 +970,9 @@ _update_frame(Evas_Object *obj)
 }
 
 static int
-_view_update(Evry_View *view)
+_view_update(Evry_View *ev)
 {
-   GET_VIEW(v, view);
+   GET_VIEW(v, ev);
    Smart_Data *sd = evas_object_smart_data_get(v->span);
    Item *v_it;
    Evry_Item *p_it;
@@ -975,7 +992,7 @@ _view_update(Evry_View *view)
 
    if (!p)
      {
-        _view_clear(view);
+        _view_clear(ev);
         return 1;
      }
 
@@ -1090,9 +1107,9 @@ _view_update(Evry_View *view)
 }
 
 static int
-_cb_key_down(Evry_View *view, const Ecore_Event_Key *ev)
+_cb_key_down(Evry_View *eview, const Ecore_Event_Key *ev)
 {
-   View *v = (View *)view;
+   View *v = (View *)eview;
    Smart_Data *sd = evas_object_smart_data_get(v->span);
    Eina_List *l = NULL, *ll;
    Item *it = NULL;
@@ -1234,7 +1251,7 @@ _cb_key_down(Evry_View *view, const Ecore_Event_Key *ev)
    if ((slide = v->tabs->key_down(v->tabs, ev)))
      {
         /* _view_update(view, -slide); */
-        _view_update(view);
+        _view_update(eview);
         return 1;
      }
 
@@ -1453,6 +1470,8 @@ _view_cb_mouse_wheel(void *data __UNUSED__, Evas *e __UNUSED__, Evas_Object *obj
      }
 }
 
+// FIXME: 'drag into' make mouse input hang after some trials 
+#if 0
 static void
 _view_cb_mouse_down(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info)
 {
@@ -1506,7 +1525,7 @@ _view_cb_mouse_move(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__,
         edje_object_signal_emit(sd->view->bg, "e,action,hide,back", "e");
         goto end;
      }
-
+   
    if ((sel->states->next) || (sel != sel->win->selectors[0]))
      edje_object_signal_emit(sd->view->bg, "e,action,show,back", "e");
 
@@ -1522,7 +1541,6 @@ _view_cb_mouse_move(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__,
              _pan_item_select(data, sd->it_down, 0);
           }
      }
-
    if (sd->mouse_button == 1)
      {
         if (ev->cur.canvas.x - sd->mouse_x > SLIDE_RESISTANCE)
@@ -1562,6 +1580,7 @@ end:
    sd->mouse_x = 0;
    sd->mouse_y = 0;
 }
+#endif
 
 static void
 _cb_list_hide(void *data, Evas_Object *obj __UNUSED__, const char *emission __UNUSED__, const char *source __UNUSED__)
@@ -1580,15 +1599,15 @@ _cb_list_show(void *data, Evas_Object *obj __UNUSED__, const char *emission __UN
 }
 
 static Evry_View *
-_view_create(Evry_View *view, const Evry_State *s, const Evas_Object *swallow)
+_view_create(Evry_View *ev, const Evry_State *s, const Evas_Object *swallow)
 {
-   GET_VIEW(parent, view);
+   GET_VIEW(parent, ev);
 
    View *v;
    Ecore_Event_Handler *h;
 
    v = E_NEW(View, 1);
-   v->view = *view;
+   v->view = *ev;
    v->state = s;
    v->evas = evas_object_evas_get(swallow);
 
@@ -1623,14 +1642,14 @@ _view_create(Evry_View *view, const Evry_State *s, const Evas_Object *swallow)
    _pan_view_set(v->span, v);
    evas_object_event_callback_add(v->span, EVAS_CALLBACK_MOUSE_WHEEL,
                                   _view_cb_mouse_wheel, NULL);
-
+#if 0
    evas_object_event_callback_add(v->bg, EVAS_CALLBACK_MOUSE_MOVE,
                                   _view_cb_mouse_move, v->span);
    evas_object_event_callback_add(v->bg, EVAS_CALLBACK_MOUSE_DOWN,
                                   _view_cb_mouse_down, v->span);
    evas_object_event_callback_add(v->bg, EVAS_CALLBACK_MOUSE_UP,
                                   _view_cb_mouse_up, v->span);
-
+#endif
    // the scrollframe holding the scrolled thumbs
    v->sframe = e_scrollframe_add(v->evas);
    e_scrollframe_custom_theme_set(v->sframe, "base/theme/modules/everything",
@@ -1661,13 +1680,13 @@ _view_create(Evry_View *view, const Evry_State *s, const Evas_Object *swallow)
 }
 
 static void
-_view_destroy(Evry_View *view)
+_view_destroy(Evry_View *ev)
 {
    Ecore_Event_Handler *h;
 
-   GET_VIEW(v, view);
+   GET_VIEW(v, ev);
 
-   _view_clear(view);
+   _view_clear(ev);
 
    evas_object_del(v->span);
    evas_object_del(v->bg);
