@@ -124,9 +124,9 @@ _e_kbd_int_layout_buf_update(E_Kbd_Int *ki)
                s3 = strdup(_e_kbd_int_str_unquote(out_capslock));
              e_kbd_buf_layout_key_add(ki->kbuf, s1, s2, s3, 
                                       ky->x, ky->y, ky->w, ky->h);
-             if (s1) free(s1);
-             if (s2) free(s2);
-             if (s3) free(s3);
+             free(s1);
+             free(s2);
+             free(s3);
           }
      }
 }
@@ -913,7 +913,7 @@ _e_kbd_int_layout_free(E_Kbd_Int *ki)
 {
    E_Kbd_Int_Key *ky;
 
-   if (ki->layout.directory) free(ki->layout.directory);
+   free(ki->layout.directory);
    if (ki->layout.file) eina_stringshare_del(ki->layout.file);
    ki->layout.directory = NULL;
    ki->layout.file = NULL;
@@ -940,7 +940,7 @@ static void
 _e_kbd_int_layout_parse(E_Kbd_Int *ki, const char *layout)
 {
    FILE *f;
-   char buf[PATH_MAX];
+   char buf[4096];
    int isok = 0;
    E_Kbd_Int_Key *ky = NULL;
    E_Kbd_Int_Key_State *st = NULL;
@@ -956,7 +956,7 @@ _e_kbd_int_layout_parse(E_Kbd_Int *ki, const char *layout)
    while (fgets(buf, sizeof(buf), f))
      {
         int len;
-        char str[PATH_MAX];
+        char str[4096];
 
         if (!isok)
           {
@@ -999,8 +999,7 @@ _e_kbd_int_layout_parse(E_Kbd_Int *ki, const char *layout)
              if (!ky) continue;
              if (sscanf(buf, "%*s %i %i %i %i\n", &(ky->x), &(ky->orig_y), &(ky->w), &(ky->orig_h)) != 4)
                {
-                  free(ky);
-                  ky = NULL;
+                  E_FREE(ky);
                   continue;
                }
              ki->layout.keys = eina_list_append(ki->layout.keys, ky);
@@ -1010,7 +1009,7 @@ _e_kbd_int_layout_parse(E_Kbd_Int *ki, const char *layout)
             (!strcmp(str, "capslock")) || (!strcmp(str, "altgr")))
           {
              char *p;
-             char label[PATH_MAX];
+             char label[4096];
 
              if (sscanf(buf, "%*s %4000s", label) != 1) continue;
              st = calloc(1, sizeof(E_Kbd_Int_Key_State));
@@ -1216,7 +1215,7 @@ _e_kbd_int_layouts_list_update(E_Kbd_Int *ki)
         kil = E_NEW(E_Kbd_Int_Layout, 1);
         if (kil)
           {
-             char *s, *p;
+             char *s;
              FILE *f;
 
              kil->path = path;
@@ -1241,7 +1240,6 @@ _e_kbd_int_layouts_list_update(E_Kbd_Int *ki)
 
                   while (fgets(buf, sizeof(buf), f))
                     {
-                       int len;
                        char str[4096];
 
                        if (!isok)
@@ -1790,7 +1788,7 @@ e_kbd_int_new(const char *themedir, const char *syskbds, const char *sysdicts)
    if (il_kbd_cfg->dict)
      ki->kbuf = e_kbd_buf_new(ki->sysdicts, il_kbd_cfg->dict);
    else
-     ki->kbuf = e_kbd_buf_new(ki->sysdicts, "English_(US).dic");
+     ki->kbuf = e_kbd_buf_new(ki->sysdicts, "English_US.dic");
 
    _e_kbd_int_layouts_list_update(ki);
 
