@@ -1,5 +1,4 @@
 #include "e_illume_private.h"
-#include "e_mod_config_animation.h"
 
 /* local function prototypes */
 static void *_e_mod_illume_config_animation_create(E_Config_Dialog *cfd);
@@ -34,7 +33,6 @@ e_mod_illume_config_animation_show(E_Container *con, const char *params __UNUSED
                              "enlightenment/animation_settings", 0, v, NULL);
    if (!cfd) return;
 
-   e_dialog_resizable_set(cfd->dia, 1);
 }
 
 /* local function prototypes */
