@@ -1,5 +1,5 @@
 #include "e_illume_private.h"
-#include "e_mod_kbd_device.h"
+#include "e_mod_main.h"
 
 /* local function prototypes */
 static void _e_mod_kbd_device_ignore_load(void);
@@ -113,7 +113,7 @@ _e_mod_kbd_device_ignore_load(void)
 static void 
 _e_mod_kbd_device_ignore_load_file(const char *file) 
 {
-   char buff[PATH_MAX];
+   char buff[4096];
    FILE *f;
 
    /* can this file be opened */
@@ -146,7 +146,7 @@ _e_mod_kbd_device_ignore_load_file(const char *file)
 
 #ifdef HAVE_EEZE
 static void 
-_e_mod_kbd_device_udev_event(const char *device, Eeze_Udev_Event event, void *data __UNUSED__, Eeze_Udev_Watch *watch __UNUSED__)
+_e_mod_kbd_device_udev_event(const char *device, Eeze_Udev_Event event, void *data __UNUSED__, Eeze_Udev_Watch *w __UNUSED__)
 {
    if ((!device) || (!event)) return;
 
