@@ -12,6 +12,7 @@
 static void _policy_border_set_focus(E_Border *bd);
 static void _policy_border_move(E_Border *bd, int x, int y);
 static void _policy_border_resize(E_Border *bd, int w, int h);
+static void _policy_border_hide_above(E_Border *bd);
 static void _policy_border_hide_below(E_Border *bd);
 static void _policy_border_show_below(E_Border *bd);
 static void _policy_zone_layout_update(E_Zone *zone);
@@ -123,25 +124,59 @@ _policy_border_resize(E_Border *bd, int w, int h)
 }
 
 static void 
-_policy_border_hide_below(E_Border *bd) 
+_policy_border_hide_above(E_Border *bd)
 {
-   int pos = 0, i;
-
-//   printf("Hide Borders Below: %s %d %d\n", 
-//          bd->client.icccm.name, bd->x, bd->y);
+   int pos = 0, layer = 0, i;
 
    if (!bd) return;
 
    /* determine layering position */
-   if (bd->layer <= 0) pos = 0;
-   else if ((bd->layer > 0) && (bd->layer <= 50)) pos = 1;
-   else if ((bd->layer > 50) && (bd->layer <= 100)) pos = 2;
-   else if ((bd->layer > 100) && (bd->layer <= 150)) pos = 3;
-   else if ((bd->layer > 150) && (bd->layer <= 200)) pos = 4;
-   else pos = 5;
+   layer = bd->layer;
+   if (layer < 0) layer = 0;
+   pos = 1 + (layer / 50);
+   if (pos > 10) pos = 10;
+
+   /* Find the windows above this one */
+   for (i = (pos + 1); i < 11; i++)
+     {
+        Eina_List *l;
+        E_Border *b;
+
+        EINA_LIST_REVERSE_FOREACH(bd->zone->container->layers[i].clients, l, b) 
+          {
+             /* skip if it's the same border */
+             if (b == bd) continue;
+
+             /* skip if it's not on this zone */
+             if (b->zone != bd->zone) continue;
+
+             /* skip special borders */
+             if (e_illume_border_is_indicator(b)) continue;
+             if (e_illume_border_is_softkey(b)) continue;
+             if (e_illume_border_is_keyboard(b)) continue;
+             if (e_illume_border_is_quickpanel(b)) continue;
+             if (e_illume_border_is_home(b)) continue;
+
+             e_border_iconify(b);
+          }
+     }
+}
+
+static void 
+_policy_border_hide_below(E_Border *bd) 
+{
+   int pos = 0, layer = 0, i;
+
+   if (!bd) return;
+
+   /* determine layering position */
+   layer = bd->layer;
+   if (layer < 0) layer = 0;
+   pos = 1 + (layer / 50);
+   if (pos > 10) pos = 10;
 
    /* Find the windows below this one */
-   for (i = pos; i >= 2; i--) 
+   for (i = (pos - 1); i >= 0; i--)
      {
         Eina_List *l;
         E_Border *b;
@@ -183,7 +218,7 @@ _policy_border_show_below(E_Border *bd)
 {
    Eina_List *l;
    E_Border *prev;
-   int pos = 0, i;
+   int pos = 0, layer = 0, i;
 
 //   printf("Show Borders Below: %s %d %d\n", 
 //          bd->client.icccm.class, bd->x, bd->y);
@@ -200,15 +235,13 @@ _policy_border_show_below(E_Border *bd)
      }
 
    /* determine layering position */
-   if (bd->layer <= 0) pos = 0;
-   else if ((bd->layer > 0) && (bd->layer <= 50)) pos = 1;
-   else if ((bd->layer > 50) && (bd->layer <= 100)) pos = 2;
-   else if ((bd->layer > 100) && (bd->layer <= 150)) pos = 3;
-   else if ((bd->layer > 150) && (bd->layer <= 200)) pos = 4;
-   else pos = 5;
+   layer = bd->layer;
+   if (layer < 0) layer = 0;
+   pos = 1 + (layer / 50);
+   if (pos > 10) pos = 10;
 
    /* Find the windows below this one */
-   for (i = pos; i >= 2; i--) 
+   for (i = (pos + 1); i < 11; i++)
      {
         E_Border *b;
 
@@ -1038,10 +1071,10 @@ _policy_zone_layout_conformant_dual_left(E_Border *bd, E_Illume_Config_Zone *cz)
 void 
 _policy_border_add(E_Border *bd) 
 {
-//   printf("Border added: %s\n", bd->client.icccm.class);
-
    if (!bd) return;
 
+//   printf("\nBorder added: %s\n", bd->client.icccm.class);
+
    /* NB: this call sets an atom on the window that specifices the zone.
     * the logic here is that any new windows created can access the zone 
     * window by a 'get' call. This is useful for elementary apps as they 
@@ -1158,7 +1191,7 @@ _policy_border_focus_in(E_Border *bd)
         /* try to get the Indicator on this zone */
         if ((ind = e_illume_border_indicator_get(bd->zone))) 
           {
-             /* we have the indicator, show it if needed */
+             /* we have the indicator, hide it if needed */
 	     if (ind->visible) e_illume_border_hide(ind);
           }
      }
@@ -1177,10 +1210,10 @@ _policy_border_focus_in(E_Border *bd)
 void 
 _policy_border_focus_out(E_Border *bd) 
 {
-//   printf("Border focus out: %s\n", bd->client.icccm.name);
-
    if (!bd) return;
 
+//   printf("Border focus out: %s\n", bd->client.icccm.name);
+
    /* NB: if we got this focus_out event on a deleted border, we check if 
     * it is a transient (child) of another window. If it is, then we 
     * transfer focus back to the parent window */
@@ -1201,10 +1234,10 @@ _policy_border_activate(E_Border *bd)
 {
    E_Border *sft;
 
-//   printf("Border Activate: %s\n", bd->client.icccm.name);
-
    if (!bd) return;
 
+   printf("Border Activate: %s\n", bd->client.icccm.name);
+
    /* NB: stolen borders may or may not need focus call...have to test */
    if (bd->stolen) return;
 
@@ -1706,7 +1739,20 @@ _policy_focus_home(E_Zone *zone)
 
    if (!zone) return;
    if (!(bd = e_illume_border_home_get(zone))) return;
-   _policy_border_set_focus(bd);
+
+   /* if the border was hidden due to layout, we need to unhide */
+   if (!bd->visible) e_illume_border_show(bd);
+
+   if ((bd->iconic) && (!bd->lock_user_iconify)) 
+     e_border_uniconify(bd);
+
+   if (!bd->lock_user_stacking) e_border_raise(bd);
+
+   /* hide the border(s) above this one */
+   _policy_border_hide_above(bd);
+
+   /* focus the border */
+   e_border_focus_set(bd, 1, 1);
 }
 
 void 
@@ -1834,7 +1880,7 @@ _policy_property_change(Ecore_X_Event_Window_Property *event)
         w = kbd->border->w;
         h = kbd->border->h;
 
-        /* adjust Y for keyboard visibility because keyboard uses fx_offset */
+        /* adjust for keyboard visibility because keyboard uses fx_offset */
         y = 0;
         if (kbd->border->fx.y <= 0) y = kbd->border->y;
 
