@@ -4,13 +4,13 @@ extern const char _e_mixer_Name[];
 
 typedef struct E_Mixer_App_Dialog_Data
 {
-   E_Mixer_System *sys;
-   const char *card;
-   const char *channel_name;
-   int lock_sliders;
-   Eina_List *cards;
-   Eina_List *channels_infos;
-   struct channel_info *channel_info;
+   E_Mixer_System       *sys;
+   const char           *card;
+   const char           *channel_name;
+   int                   lock_sliders;
+   Eina_List            *cards;
+   Eina_List            *channels_infos;
+   struct channel_info  *channel_info;
    E_Mixer_Channel_State state;
 
    struct e_mixer_app_ui
@@ -53,9 +53,9 @@ typedef struct E_Mixer_App_Dialog_Data
 
 struct channel_info
 {
-   int has_capture;
-   const char *name;
-   E_Mixer_Channel *id;
+   int                      has_capture;
+   const char              *name;
+   E_Mixer_Channel         *id;
    E_Mixer_App_Dialog_Data *app;
 };
 
@@ -68,13 +68,13 @@ _cb_changed_left(void *data, Evas_Object *obj __UNUSED__)
    state = &app->state;
    if (app->lock_sliders && (state->left != state->right))
      {
-	state->right = state->left;
-	e_widget_slider_value_int_set(app->ui.channel_editor.right,
-				      state->right);
+        state->right = state->left;
+        e_widget_slider_value_int_set(app->ui.channel_editor.right,
+                                      state->right);
      }
 
    e_mod_mixer_volume_set(app->sys, app->channel_info->id,
-                             state->left, state->right);
+                          state->left, state->right);
 }
 
 static void
@@ -86,13 +86,13 @@ _cb_changed_right(void *data, Evas_Object *obj __UNUSED__)
    state = &app->state;
    if (app->lock_sliders && (state->right != state->left))
      {
-	state->left = state->right;
-	e_widget_slider_value_int_set(app->ui.channel_editor.left,
-				      state->left);
+        state->left = state->right;
+        e_widget_slider_value_int_set(app->ui.channel_editor.left,
+                                      state->left);
      }
 
    e_mod_mixer_volume_set(app->sys, app->channel_info->id,
-                             state->left, state->right);
+                          state->left, state->right);
 }
 
 static void
@@ -121,7 +121,27 @@ _cb_changed_lock_sliders(void *data, Evas_Object *obj __UNUSED__)
    e_widget_slider_value_int_set(app->ui.channel_editor.left, state->left);
    e_widget_slider_value_int_set(app->ui.channel_editor.right, state->right);
    e_mod_mixer_volume_set(app->sys, app->channel_info->id,
-                             state->left, state->right);
+                          state->left, state->right);
+}
+
+static void
+_disable_channel_editor(E_Mixer_App_Dialog_Data *app)
+{
+   struct e_mixer_app_ui_channel_editor *ui = &app->ui.channel_editor;
+
+   e_widget_entry_text_set(ui->card, "");
+   e_widget_entry_text_set(ui->channel, "");
+   e_widget_entry_text_set(ui->type, "");
+
+   e_widget_slider_value_int_set(ui->left, 0);
+   e_widget_slider_value_int_set(ui->right, 0);
+   e_widget_check_checked_set(ui->mute, 0);
+   e_widget_check_checked_set(ui->lock_sliders, 0);
+
+   e_widget_disabled_set(ui->left, 1);
+   e_widget_disabled_set(ui->right, 1);
+   e_widget_disabled_set(ui->mute, 1);
+   e_widget_disabled_set(ui->lock_sliders, 1);
 }
 
 static void
@@ -129,18 +149,22 @@ _update_channel_editor_state(E_Mixer_App_Dialog_Data *app, const E_Mixer_Channel
 {
    struct e_mixer_app_ui_channel_editor *ui = &app->ui.channel_editor;
 
+   e_widget_disabled_set(ui->left, 0);
+   e_widget_disabled_set(ui->right, 0);
+   e_widget_disabled_set(ui->lock_sliders, 0);
+
    e_widget_slider_value_int_set(ui->left, state.left);
    e_widget_slider_value_int_set(ui->right, state.right);
 
    if (e_mod_mixer_mutable_get(app->sys, app->channel_info->id))
      {
-	e_widget_disabled_set(ui->mute, 0);
-	e_widget_check_checked_set(ui->mute, state.mute);
+        e_widget_disabled_set(ui->mute, 0);
+        e_widget_check_checked_set(ui->mute, state.mute);
      }
    else
      {
-	e_widget_disabled_set(ui->mute, 1);
-	e_widget_check_checked_set(ui->mute, 0);
+        e_widget_disabled_set(ui->mute, 1);
+        e_widget_check_checked_set(ui->mute, 0);
      }
 }
 
@@ -152,6 +176,13 @@ _populate_channel_editor(E_Mixer_App_Dialog_Data *app)
    const char *card_name;
 
    card_name = e_mod_mixer_card_name_get(app->card);
+   
+   if (!card_name)
+     {
+        _disable_channel_editor(app);
+        return;
+     }
+   
    e_widget_entry_text_set(ui->card, card_name);
    eina_stringshare_del(card_name);
 
@@ -202,14 +233,14 @@ _channels_info_new(E_Mixer_System *sys)
    channels_infos = NULL;
    for (l = channels; l; l = l->next)
      {
-	struct channel_info *info;
+        struct channel_info *info;
 
-	info = malloc(sizeof(*info));
-	info->id = l->data;
-	info->name = e_mod_mixer_channel_name_get(sys, info->id);
-	info->has_capture = e_mod_mixer_capture_get(sys, info->id);
+        info = malloc(sizeof(*info));
+        info->id = l->data;
+        info->name = e_mod_mixer_channel_name_get(sys, info->id);
+        info->has_capture = e_mod_mixer_capture_get(sys, info->id);
 
-	channels_infos = eina_list_append(channels_infos, info);
+        channels_infos = eina_list_append(channels_infos, info);
      }
    e_mod_mixer_channels_free(channels);
 
@@ -223,8 +254,8 @@ _channels_info_free(Eina_List *list)
 
    EINA_LIST_FREE(list, info)
      {
-	eina_stringshare_del(info->name);
-	free(info);
+        eina_stringshare_del(info->name);
+        free(info);
      }
 }
 
@@ -264,7 +295,7 @@ _populate_channels(E_Mixer_App_Dialog_Data *app)
 
    eina_stringshare_del(app->channel_name);
    app->channel_name = e_mod_mixer_channel_default_name_get(app->sys);
-   
+
    if (app->channels_infos)
      _channels_info_free(app->channels_infos);
    app->channels_infos = _channels_info_new(app->sys);
@@ -299,9 +330,9 @@ _populate_channels(E_Mixer_App_Dialog_Data *app)
 
         info->app = app;
         e_widget_ilist_append(ilist, NULL, info->name, _cb_channel_selected,
-                info, info->name);
+                              info, info->name);
         if (app->channel_name && info->name &&
-                   (strcmp(app->channel_name, info->name) == 0))
+            (strcmp(app->channel_name, info->name) == 0))
           {
              e_widget_ilist_selected_set(ilist, i);
              app->channel_info = info;
@@ -317,7 +348,10 @@ static void
 select_card(E_Mixer_App_Dialog_Data *app)
 {
    _populate_channels(app);
-   e_widget_ilist_selected_set(app->ui.channels.list, 1);
+   if (e_widget_ilist_count(app->ui.channels.list) > 0)
+     e_widget_ilist_selected_set(app->ui.channels.list, 1);
+   else
+     _disable_channel_editor(app);
 }
 
 static void
@@ -343,14 +377,17 @@ _create_cards(E_Dialog *dialog __UNUSED__, Evas *evas, E_Mixer_App_Dialog_Data *
    e_widget_ilist_go(ui->list);
    EINA_LIST_FOREACH(app->cards, l, card)
      {
-	const char *card_name;
+        const char *card_name;
 
-	card_name = e_mod_mixer_card_name_get(card);
+        card_name = e_mod_mixer_card_name_get(card);
+        
+        if (!card_name)
+          continue;
 
-	e_widget_ilist_append(ui->list, NULL, card_name, _cb_card_selected,
-			      app, card);
+        e_widget_ilist_append(ui->list, NULL, card_name, _cb_card_selected,
+                              app, card);
 
-	eina_stringshare_del(card_name);
+        eina_stringshare_del(card_name);
      }
 
    ui->frame = e_widget_framelist_add(evas, _("Cards"), 0);
@@ -496,8 +533,8 @@ e_mixer_app_dialog_new(E_Container *con, void (*func)(E_Dialog *dialog, void *da
    app = E_NEW(E_Mixer_App_Dialog_Data, 1);
    if (!app)
      {
-	e_object_del(E_OBJECT(dialog));
-	return NULL;
+        e_object_del(E_OBJECT(dialog));
+        return NULL;
      }
 
    dialog->data = app;
@@ -505,7 +542,6 @@ e_mixer_app_dialog_new(E_Container *con, void (*func)(E_Dialog *dialog, void *da
    app->del.func = func;
 
    e_dialog_title_set(dialog, _(_e_mixer_Name));
-   e_dialog_resizable_set(dialog, 1);
 
    e_win_delete_callback_set(dialog->win, _cb_win_del);
 
@@ -528,6 +564,9 @@ _find_card_by_name(E_Mixer_App_Dialog_Data *app, const char *card_name)
    Eina_List *l;
    int i;
 
+   if (!card_name)
+     return 0;
+   
    for (i = 0, l = app->cards; l; i++, l = l->next)
      if (strcmp(card_name, l->data) == 0)
        return i;
@@ -543,26 +582,29 @@ _find_channel_by_name(E_Mixer_App_Dialog_Data *app, const char *channel_name)
    int i = 0;
    int header_input;
 
+   if (!channel_name)
+     return 0;
+   
    if (app->channels_infos)
      {
-	struct channel_info *info = app->channels_infos->data;
+        info = app->channels_infos->data;
 
-	header_input = !!info->has_capture;
-	i = 1;
+        header_input = !!info->has_capture;
+        i = 1;
      }
 
    EINA_LIST_FOREACH(app->channels_infos, l, info)
      {
-	if ((!header_input) && info->has_capture)
-	  {
-	     header_input = 1;
-	     i++;
-	  }
+        if ((!header_input) && info->has_capture)
+          {
+             header_input = 1;
+             i++;
+          }
 
-	if (strcmp(channel_name, info->name) == 0)
-	  return i;
+        if (strcmp(channel_name, info->name) == 0)
+          return i;
 
-	++i;
+        ++i;
      }
 
    return -1;
@@ -576,6 +618,9 @@ e_mixer_app_dialog_select(E_Dialog *dialog, const char *card_name, const char *c
 
    if (!dialog)
      return 0;
+   
+   if ((!card_name) || (!channel_name))
+     return 0;
 
    app = dialog->data;
    if (!app)
@@ -594,3 +639,4 @@ e_mixer_app_dialog_select(E_Dialog *dialog, const char *card_name, const char *c
 
    return 1;
 }
+
