@@ -1,13 +1,30 @@
 #ifndef E_MOD_MAIN_H
 #define E_MOD_MAIN_H
 
+#include "e.h"
+
 #ifdef HAVE_EEZE
 # include <Eeze.h>
 #else
 # include <E_Hal.h>
 #endif
 
-#include "e_mod_main_private.h"
+
+typedef enum _Sensor_Type
+{
+   SENSOR_TYPE_NONE,
+   SENSOR_TYPE_FREEBSD,
+   SENSOR_TYPE_OPENBSD,
+   SENSOR_TYPE_OMNIBOOK,
+   SENSOR_TYPE_LINUX_MACMINI,
+   SENSOR_TYPE_LINUX_I2C,
+   SENSOR_TYPE_LINUX_ACPI,
+   SENSOR_TYPE_LINUX_PCI,
+   SENSOR_TYPE_LINUX_PBOOK,
+   SENSOR_TYPE_LINUX_INTELCORETEMP,
+   SENSOR_TYPE_LINUX_THINKPAD,
+   SENSOR_TYPE_LINUX_SYS
+} Sensor_Type;
 
 typedef struct _Config Config;
 typedef struct _Config_Face Config_Face;
